@@ -42,6 +42,9 @@ mod lookup;
 mod recursive;
 mod utility;
 
+pub const ZFS_HIDDEN_DIRECTORY: &str = ".zfs";
+pub const ZFS_HIDDEN_SNAPSHOT_DIRECTORY: &str = ".zfs/snapshot";
+
 #[derive(Debug)]
 pub struct HttmError {
     details: String,
@@ -272,9 +275,16 @@ impl Config {
         // here we determine how we will obtain our snap point -- has the user defined it
         // or will we find it by searching the native filesystem?
         let (opt_alt_replicated, snap_point) = if let Some(raw_value) = raw_snap_var {
+            if matches.is_present("ALT_REPLICATED") {
+                return Err(HttmError::new(
+                    "Alternate replicated datasets are not available for search, when the user defines a snap point.",
+                )
+                .into());
+            }
+
             // user defined dir exists?: check that path contains the hidden snapshot directory
             let path = PathBuf::from(raw_value);
-            let hidden_snap_dir = path.join(".zfs").join("snapshot");
+            let hidden_snap_dir = path.join(ZFS_HIDDEN_SNAPSHOT_DIRECTORY);
 
             // little sanity check -- make sure the user defined snap dir exist
             let snap_dir = if hidden_snap_dir.metadata().is_ok() {
@@ -356,15 +366,10 @@ impl Config {
         // deduplicate pathdata and sort if in display mode --
         // so input of ./.z* and ./.zshrc will only print ./.zshrc once
         paths = if exec_mode == ExecMode::Display && paths.len() > 1 {
-            let unique_paths: HashMap<PathBuf, PathData> = paths
-                .into_par_iter()
-                .map(|pathdata| (pathdata.path_buf.clone(), pathdata))
-                .collect();
+            paths.sort_by_key(|pathdata| pathdata.path_buf.to_owned());
+            paths.dedup_by_key(|pathdata| pathdata.path_buf.to_owned());
 
-            let mut sorted: Vec<PathData> = unique_paths.into_par_iter().map(|(_, v)| v).collect();
-            sorted.par_sort_unstable_by_key(|pathdata| pathdata.path_buf.clone());
-
-            sorted
+            paths
         } else {
             paths
         };
